? .cvsignore
? .deps
? .libs
? Makefile
? Makefile.in
? silky
Index: silccallbacks.c
===================================================================
RCS file: /cvsroot/silky/silky/src/silccallbacks.c,v
retrieving revision 1.77
diff -u -3 -p -u -r1.77 silccallbacks.c
--- silccallbacks.c	3 Nov 2003 00:35:28 -0000	1.77
+++ silccallbacks.c	8 Nov 2003 13:51:00 -0000
@@ -1444,6 +1444,40 @@ static void silc_disconnected(SilcClient
   printconsole(g_strdup_printf("silky: %s ;; %s\n", silc_get_status_message(status), msg));
 }
 
+
+typedef struct {
+  SilcGetAuthMeth completion;
+  void *context;
+} *InternalGetAuthMethod;
+
+/* Callback called when we've received the authentication method information
+   from the server after we've requested it. This will get the authentication
+   data from the user if needed. */
+static void silc_get_auth_method_callback(SilcClient client,
+					  SilcClientConnection conn,
+					  SilcAuthMethod auth_meth,
+					  void *context)
+{
+  InternalGetAuthMethod internal = (InternalGetAuthMethod)context;
+
+  debug(("silc_get_auth_method_callback"));
+
+  switch (auth_meth) {
+  case SILC_AUTH_NONE:
+    /* No authentication required. */
+    (*internal->completion)(TRUE, auth_meth, NULL, 0, internal->context);
+    break;
+  case SILC_AUTH_PUBLIC_KEY:
+    /* Do not get the authentication data now, the library will generate
+       it using our default key, if we do not provide it here. */
+    /* XXX In the future when we support multiple local keys and multiple
+       local certificates we will need to ask from user which one to use. */
+    (*internal->completion)(TRUE, auth_meth, NULL, 0, internal->context);
+    break;
+  }
+  silc_free(internal);
+}
+
 /*
   Find authentication method and auth data by hostname and port info.
   Hostname may be IP-address as well.
@@ -1451,14 +1485,20 @@ static void silc_disconnected(SilcClient
 static void silc_get_auth_method(SilcClient client, SilcClientConnection conn,
                                  char *hostname, SilcUInt16 port,
                                  SilcGetAuthMeth completion, void *context) {
+  InternalGetAuthMethod internal;
 
   debug("silc_get_auth_method()\n");
 
-  /* 
-     silky does not authenticate to the server
-     Just reply with TRUE to signal key's acceptance.
-  */
-	completion(TRUE, SILC_AUTH_NONE, NULL, 0, context);
+  /* If we do not have this connection configured by the user in a
+     configuration file then resolve the authentication method from the
+     server for this session. */
+  internal = silc_calloc(1, sizeof(*internal));
+  internal->completion = completion;
+  internal->context = context;
+
+  silc_client_request_authentication_method(client, conn,
+					    silc_get_auth_method_callback,
+					    internal);
 }
 
 /*
